/*
 * JDesktopTester.java - Test application for WindowManager
 *
 * Copyright (c) 2004 Gregory Kotsaftis
 * gregkotsaftis@yahoo.com
 * http://zeus-jscl.sourceforge.net/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package gr.zeus.tests;

import gr.zeus.ui.mdi.WindowManager;
import java.awt.Dimension;
import java.awt.Toolkit;
import javax.swing.JDesktopPane;
import javax.swing.JInternalFrame;
import javax.swing.JLabel;
import javax.swing.JLayeredPane;
import javax.swing.UIManager;


public class JDesktopTester extends javax.swing.JFrame {
    
    private WindowManager m_windowManager = null;
    
    
    public JDesktopTester()
    {
        initComponents();
        
        // open some frames BEFORE we attach our window manager, to prove
        // we can handle even those frames...
        JInternalFrame jif1 = new JInternalFrame();
        jif1.setResizable( true );
        jif1.setMaximizable( true );
        jif1.setClosable( true );
        jif1.setIconifiable( true );
        jif1.setDefaultCloseOperation( JInternalFrame.DISPOSE_ON_CLOSE );
        jif1.setTitle("1_DISPOSE_ON_CLOSE");
        jif1.setPreferredSize( new Dimension(300, 300) );
        jif1.setBounds(0, 0, 300, 300);
        jif1.setVisible( true );
        desktopPane.add(jif1, JLayeredPane.DEFAULT_LAYER);
        
        JInternalFrame jif2 = new JInternalFrame();
        jif2.setResizable( true );
        jif2.setMaximizable( true );
        jif2.setClosable( true );
        jif2.setIconifiable( true );
        jif2.setDefaultCloseOperation( JInternalFrame.HIDE_ON_CLOSE );
        jif2.setTitle("2_HIDE_ON_CLOSE");
        jif2.setPreferredSize( new Dimension(200, 200) );
        jif2.setBounds(20, 10, 200, 200);
        jif2.setVisible( true );
        desktopPane.add(jif2, JLayeredPane.DEFAULT_LAYER);
                
        // attach our window manager        
        m_windowManager = new WindowManager(desktopPane, windowMenu);
        
        // display the default properties
        outlineDragModeMenuItem.setSelected( m_windowManager.getOutlineDragMode() );
        deiconifiablePolicyMenuItem.setSelected( m_windowManager.getDeiconifiablePolicy() );
        closePolicyMenuItem.setSelected( m_windowManager.getClosePolicy() );
    }
    
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    private void initComponents() {//GEN-BEGIN:initComponents
        desktopPane = new javax.swing.JDesktopPane();
        menuBar = new javax.swing.JMenuBar();
        fileMenu = new javax.swing.JMenu();
        newMenuItem = new javax.swing.JMenuItem();
        countFramesMenuItem = new javax.swing.JMenuItem();
        exitMenuItem = new javax.swing.JMenuItem();
        windowMenu = new javax.swing.JMenu();
        outlineDragModeMenuItem = new javax.swing.JCheckBoxMenuItem();
        deiconifiablePolicyMenuItem = new javax.swing.JCheckBoxMenuItem();
        autoPositionMenuItem = new javax.swing.JCheckBoxMenuItem();
        closePolicyMenuItem = new javax.swing.JCheckBoxMenuItem();
        jSeparator1 = new javax.swing.JSeparator();
        cascadeMenuItem = new javax.swing.JMenuItem();
        tileHMenuItem = new javax.swing.JMenuItem();
        tileVMenuItem = new javax.swing.JMenuItem();
        tileMenuItem = new javax.swing.JMenuItem();
        nextMenuItem = new javax.swing.JMenuItem();
        previousMenuItem = new javax.swing.JMenuItem();
        jSeparator2 = new javax.swing.JSeparator();
        minimizeMenuItem = new javax.swing.JMenuItem();
        minimizeAllMenuItem = new javax.swing.JMenuItem();
        restoreMenuItem = new javax.swing.JMenuItem();
        restoreAllMenuItem = new javax.swing.JMenuItem();
        maximizeMenuItem = new javax.swing.JMenuItem();
        maximizeAllMenuItem = new javax.swing.JMenuItem();
        resetMenuItem = new javax.swing.JMenuItem();
        resetAllMenuItem = new javax.swing.JMenuItem();
        jSeparator3 = new javax.swing.JSeparator();
        hideMenuItem = new javax.swing.JMenuItem();
        hideAllMenuItem = new javax.swing.JMenuItem();
        closeMenuItem = new javax.swing.JMenuItem();
        closeAllMenuItem = new javax.swing.JMenuItem();

        setTitle("WindowManager Tester");
        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        getContentPane().add(desktopPane, java.awt.BorderLayout.CENTER);

        fileMenu.setText("File");
        newMenuItem.setText("Open");
        newMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                newMenuItemActionPerformed(evt);
            }
        });

        fileMenu.add(newMenuItem);

        countFramesMenuItem.setText("Count Frames");
        countFramesMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                countFramesMenuItemActionPerformed(evt);
            }
        });

        fileMenu.add(countFramesMenuItem);

        exitMenuItem.setText("Exit");
        exitMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                exitMenuItemActionPerformed(evt);
            }
        });

        fileMenu.add(exitMenuItem);

        menuBar.add(fileMenu);

        windowMenu.setText("Window");
        outlineDragModeMenuItem.setText("Outline Drag Mode");
        outlineDragModeMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                outlineDragModeMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(outlineDragModeMenuItem);

        deiconifiablePolicyMenuItem.setText("De-iconify during cascade / tile");
        deiconifiablePolicyMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deiconifiablePolicyMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(deiconifiablePolicyMenuItem);

        autoPositionMenuItem.setText("Auto Position Frames");
        autoPositionMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                autoPositionMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(autoPositionMenuItem);

        closePolicyMenuItem.setText("Default Close Operation vs Close");
        closePolicyMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                closePolicyMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(closePolicyMenuItem);

        windowMenu.add(jSeparator1);

        cascadeMenuItem.setText("Cascade");
        cascadeMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cascadeMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(cascadeMenuItem);

        tileHMenuItem.setText("Tile Horizontal");
        tileHMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                tileHMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(tileHMenuItem);

        tileVMenuItem.setText("Tile Vertical");
        tileVMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                tileVMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(tileVMenuItem);

        tileMenuItem.setText("Tile");
        tileMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                tileMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(tileMenuItem);

        nextMenuItem.setText("Next Window");
        nextMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                nextMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(nextMenuItem);

        previousMenuItem.setText("Previous Window");
        previousMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                previousMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(previousMenuItem);

        windowMenu.add(jSeparator2);

        minimizeMenuItem.setText("Minimize");
        minimizeMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                minimizeMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(minimizeMenuItem);

        minimizeAllMenuItem.setText("Minimize All");
        minimizeAllMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                minimizeAllMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(minimizeAllMenuItem);

        restoreMenuItem.setText("Restore");
        restoreMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                restoreMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(restoreMenuItem);

        restoreAllMenuItem.setText("Restore All");
        restoreAllMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                restoreAllMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(restoreAllMenuItem);

        maximizeMenuItem.setText("Maximize");
        maximizeMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                maximizeMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(maximizeMenuItem);

        maximizeAllMenuItem.setText("Maximize All");
        maximizeAllMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                maximizeAllMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(maximizeAllMenuItem);

        resetMenuItem.setText("Reset Window");
        resetMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                resetMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(resetMenuItem);

        resetAllMenuItem.setText("Reset All Windows");
        resetAllMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                resetAllMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(resetAllMenuItem);

        windowMenu.add(jSeparator3);

        hideMenuItem.setText("Hide");
        hideMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                hideMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(hideMenuItem);

        hideAllMenuItem.setText("Hide All");
        hideAllMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                hideAllMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(hideAllMenuItem);

        closeMenuItem.setText("Close");
        closeMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                closeMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(closeMenuItem);

        closeAllMenuItem.setText("Close All");
        closeAllMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                closeAllMenuItemActionPerformed(evt);
            }
        });

        windowMenu.add(closeAllMenuItem);

        menuBar.add(windowMenu);

        setJMenuBar(menuBar);

        java.awt.Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        setBounds((screenSize.width-800)/2, (screenSize.height-600)/2, 800, 600);
    }//GEN-END:initComponents

    private void autoPositionMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_autoPositionMenuItemActionPerformed
        
        System.out.println("TODO!");
        
    }//GEN-LAST:event_autoPositionMenuItemActionPerformed

    private void closePolicyMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_closePolicyMenuItemActionPerformed
        
        m_windowManager.setClosePolicy( closePolicyMenuItem.isSelected() );
        
    }//GEN-LAST:event_closePolicyMenuItemActionPerformed

    private void hideAllMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_hideAllMenuItemActionPerformed
        
        m_windowManager.hideAll();
        
    }//GEN-LAST:event_hideAllMenuItemActionPerformed

    private void outlineDragModeMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_outlineDragModeMenuItemActionPerformed
        
        m_windowManager.setOutlineDragMode( outlineDragModeMenuItem.isSelected() );
        
    }//GEN-LAST:event_outlineDragModeMenuItemActionPerformed

    private void resetAllMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_resetAllMenuItemActionPerformed
        
        m_windowManager.resetAll();
        
    }//GEN-LAST:event_resetAllMenuItemActionPerformed

    private void resetMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_resetMenuItemActionPerformed
        
        m_windowManager.reset();
        
    }//GEN-LAST:event_resetMenuItemActionPerformed

    private void maximizeAllMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_maximizeAllMenuItemActionPerformed
        
        m_windowManager.maximizeAll();
        
    }//GEN-LAST:event_maximizeAllMenuItemActionPerformed

    private void restoreAllMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_restoreAllMenuItemActionPerformed
        
        m_windowManager.restoreAll();
        
    }//GEN-LAST:event_restoreAllMenuItemActionPerformed

    private void countFramesMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_countFramesMenuItemActionPerformed
        
        System.out.println("All Frames: " + m_windowManager.countFrames() +
            " Visible Frames: " + m_windowManager.countVisibleFrames());
        
    }//GEN-LAST:event_countFramesMenuItemActionPerformed

    private void deiconifiablePolicyMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deiconifiablePolicyMenuItemActionPerformed
        
        m_windowManager.setDeiconifiablePolicy( deiconifiablePolicyMenuItem.isSelected() );
        
    }//GEN-LAST:event_deiconifiablePolicyMenuItemActionPerformed

    private void maximizeMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_maximizeMenuItemActionPerformed
        
        m_windowManager.maximize();
        
    }//GEN-LAST:event_maximizeMenuItemActionPerformed

    private void restoreMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_restoreMenuItemActionPerformed
        
        m_windowManager.restore();
        
    }//GEN-LAST:event_restoreMenuItemActionPerformed

    private void minimizeAllMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_minimizeAllMenuItemActionPerformed
        
        m_windowManager.minimizeAll();
        
    }//GEN-LAST:event_minimizeAllMenuItemActionPerformed

    private void minimizeMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_minimizeMenuItemActionPerformed
        
        m_windowManager.minimize();
        
    }//GEN-LAST:event_minimizeMenuItemActionPerformed

    private void closeAllMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_closeAllMenuItemActionPerformed
        
        m_windowManager.closeAll();
        
    }//GEN-LAST:event_closeAllMenuItemActionPerformed

    private void closeMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_closeMenuItemActionPerformed
        
        m_windowManager.close();
        
    }//GEN-LAST:event_closeMenuItemActionPerformed

    private void hideMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_hideMenuItemActionPerformed
        
        m_windowManager.hide();
        
    }//GEN-LAST:event_hideMenuItemActionPerformed

    private void previousMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_previousMenuItemActionPerformed
        
        m_windowManager.selectPrevious();
        
    }//GEN-LAST:event_previousMenuItemActionPerformed

    private void nextMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_nextMenuItemActionPerformed
        
        m_windowManager.selectNext();
        
    }//GEN-LAST:event_nextMenuItemActionPerformed

    private void tileMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_tileMenuItemActionPerformed
        
        m_windowManager.tile();
        
    }//GEN-LAST:event_tileMenuItemActionPerformed

    private void tileVMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_tileVMenuItemActionPerformed
        
        m_windowManager.tileVertically();
        
    }//GEN-LAST:event_tileVMenuItemActionPerformed

    private void tileHMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_tileHMenuItemActionPerformed
        
        m_windowManager.tileHorizontally();
        
    }//GEN-LAST:event_tileHMenuItemActionPerformed

    private void cascadeMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_cascadeMenuItemActionPerformed
        
        m_windowManager.cascade();
        
    }//GEN-LAST:event_cascadeMenuItemActionPerformed

    private void newMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_newMenuItemActionPerformed
        
        // open some different frames to test the window manager
  
        JInternalFrame jif3 = new JInternalFrame();
        jif3.setResizable( false );
        jif3.setMaximizable( false );
        jif3.setClosable( true );
        jif3.setIconifiable( true );
        jif3.setDefaultCloseOperation( JInternalFrame.DISPOSE_ON_CLOSE );
        jif3.setTitle("3_no resize/maximize");
        jif3.setPreferredSize( new Dimension(350, 350) );
        jif3.setMaximumSize( new Dimension(350, 350) );
        jif3.setMinimumSize( new Dimension(350, 350) );
        jif3.setBounds(10, 20, 350, 350);
        jif3.setVisible( true );
        desktopPane.add(jif3, JLayeredPane.DEFAULT_LAYER);
        
        JInternalFrame jif4 = new JInternalFrame();
        jif4.setResizable( true );
        jif4.setMaximizable( true );
        jif4.setClosable( false );
        jif4.setIconifiable( false );
        jif4.setDefaultCloseOperation( JInternalFrame.DISPOSE_ON_CLOSE );
        jif4.setTitle("4_no closeable/iconifiable");
        jif4.setPreferredSize( new Dimension(350, 100) );
        jif4.setBounds(35, 10, 350, 100);
        jif4.setVisible( true );
        desktopPane.add(jif4, JLayeredPane.DEFAULT_LAYER);
        
        JInternalFrame jif5 = new JInternalFrame();
        jif5.setResizable( false );
        jif5.setMaximizable( false );
        jif5.setClosable( false );
        jif5.setIconifiable( false );
        jif5.setDefaultCloseOperation( JInternalFrame.DISPOSE_ON_CLOSE );
        jif5.setTitle("5_no resize/maximize/closeable/iconifiable");
        jif5.setPreferredSize( new Dimension(400, 400) );
        jif5.setMaximumSize( new Dimension(400, 400) );
        jif5.setMinimumSize( new Dimension(400, 400) );
        jif5.setBounds(15, 30, 400, 400);
        jif5.setVisible( true );
        desktopPane.add(jif5, JLayeredPane.DEFAULT_LAYER);
        
        JInternalFrame jif6 = new JInternalFrame();
        jif6.setResizable( true );
        jif6.setMaximizable( true );
        jif6.setClosable( true );
        jif6.setIconifiable( true );
        jif6.setDefaultCloseOperation( JInternalFrame.DISPOSE_ON_CLOSE );
        jif6.setTitle( null );
        jif6.setPreferredSize( new Dimension(100, 100) );
        jif6.setBounds(50, 60, 100, 100);
        jif6.setVisible( true );
        jif6.getContentPane().add(new JLabel("null title"));
        desktopPane.add(jif6, JLayeredPane.DEFAULT_LAYER);

        JInternalFrame jif7 = new JInternalFrame();
        jif7.setResizable( true );
        jif7.setMaximizable( true );
        jif7.setClosable( true );
        jif7.setIconifiable( true );
        jif7.setDefaultCloseOperation( JInternalFrame.DISPOSE_ON_CLOSE );
        jif7.setTitle("");
        jif7.setPreferredSize( new Dimension(150, 150) );
        jif7.setBounds(60, 40, 150, 150);
        jif7.setVisible( true );
        jif7.getContentPane().add(new JLabel("empty title"));
        desktopPane.add(jif7, JLayeredPane.DEFAULT_LAYER);

    }//GEN-LAST:event_newMenuItemActionPerformed
    
    private void exitMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_exitMenuItemActionPerformed
        
        System.exit(0);
        
    }//GEN-LAST:event_exitMenuItemActionPerformed
    
    
    /**
     * @param args the command line arguments
     */
    public static void main(String args[])
    {
        try
        {
            UIManager.setLookAndFeel( UIManager.getSystemLookAndFeelClassName() );
        }
        catch( Exception e )
        {
            e.printStackTrace();
        }
        
        new JDesktopTester().show();
    }
    
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JCheckBoxMenuItem autoPositionMenuItem;
    private javax.swing.JMenuItem cascadeMenuItem;
    private javax.swing.JMenuItem closeAllMenuItem;
    private javax.swing.JMenuItem closeMenuItem;
    private javax.swing.JCheckBoxMenuItem closePolicyMenuItem;
    private javax.swing.JMenuItem countFramesMenuItem;
    private javax.swing.JCheckBoxMenuItem deiconifiablePolicyMenuItem;
    private javax.swing.JDesktopPane desktopPane;
    private javax.swing.JMenuItem exitMenuItem;
    private javax.swing.JMenu fileMenu;
    private javax.swing.JMenuItem hideAllMenuItem;
    private javax.swing.JMenuItem hideMenuItem;
    private javax.swing.JSeparator jSeparator1;
    private javax.swing.JSeparator jSeparator2;
    private javax.swing.JSeparator jSeparator3;
    private javax.swing.JMenuItem maximizeAllMenuItem;
    private javax.swing.JMenuItem maximizeMenuItem;
    private javax.swing.JMenuBar menuBar;
    private javax.swing.JMenuItem minimizeAllMenuItem;
    private javax.swing.JMenuItem minimizeMenuItem;
    private javax.swing.JMenuItem newMenuItem;
    private javax.swing.JMenuItem nextMenuItem;
    private javax.swing.JCheckBoxMenuItem outlineDragModeMenuItem;
    private javax.swing.JMenuItem previousMenuItem;
    private javax.swing.JMenuItem resetAllMenuItem;
    private javax.swing.JMenuItem resetMenuItem;
    private javax.swing.JMenuItem restoreAllMenuItem;
    private javax.swing.JMenuItem restoreMenuItem;
    private javax.swing.JMenuItem tileHMenuItem;
    private javax.swing.JMenuItem tileMenuItem;
    private javax.swing.JMenuItem tileVMenuItem;
    private javax.swing.JMenu windowMenu;
    // End of variables declaration//GEN-END:variables
    
}
