/*
 * OutLookToolBar.java - Takes a simple JToolBar and transforms it into an
 *                       outlook like toolbar!
 *
 * Copyright (c) 2004 Gregory Kotsaftis
 * gregkotsaftis@yahoo.com
 * http://zeus-jscl.sourceforge.net/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package gr.zeus.ui;

import java.awt.Component;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import javax.swing.JButton;
import javax.swing.JToolBar;


public class OutLookToolBar {
    
    private JToolBar m_toolbar = null;
    
    
    public OutLookToolBar(JToolBar t)
    {
        m_toolbar = t;
        
        if( m_toolbar == null )
        {
            throw new NullPointerException("JToolBar instance required for OutLookToolBar is NULL!");            
        }
    }
    
    
    public void transform()
    {
        if( m_toolbar != null )
        {
            int count = m_toolbar.getComponentCount();
            
            for(int i=0; i<count; i++)
            {
                Component c = m_toolbar.getComponentAtIndex( i );
                
                if( c instanceof JButton )
                {
                    JButton b = (JButton) c;
                    b.setBorderPainted( false );
                    b.setFocusPainted( false );
                    b.addMouseListener( new MouseOver() );
                }
            }
        }
    }
    
    
    /**
     * private class to handle the mouseover behavior.
     */
    private class MouseOver implements MouseListener {
        
        public void mouseEntered(MouseEvent e)
        {
            Component c = e.getComponent();
            if( c instanceof JButton )
            {
                JButton b = (JButton) c;
                b.setBorderPainted( true );
            }
        }
        
        public void mouseExited(MouseEvent e)
        {
            Component c = e.getComponent();
            if( c instanceof JButton )
            {
                JButton b = (JButton) c;
                b.setBorderPainted( false );
            }
        }

        public void mouseClicked(MouseEvent e)
        {
        }
        
        public void mousePressed(MouseEvent e)
        {
        }
        
        public void mouseReleased(MouseEvent e)
        {
        }
        
    }
    
}
