/*
 * BevelArrowIcon.java - Bevel Arrow Icon for table header for TableSorter,
 *                       original code from: http://www.senun.com/Left/
 *                       Programming/Java_old/Examples_swing/SwingExamples.html
 *
 * Copyright (c) 2004 Gregory Kotsaftis
 * gregkotsaftis@yahoo.com
 * http://zeus-jscl.sourceforge.net/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package gr.zeus.ui.table.sort;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import javax.swing.Icon;
import javax.swing.UIManager;


public class BevelArrowIcon implements Icon {

    private static final int DEFAULT_SIZE = 11;

    private Color m_edge1;
    private Color m_edge2;
    private Color m_fill;
    private int m_size;
    private int m_direction;

    
    public BevelArrowIcon(int direction, boolean isRaisedView, boolean isPressedView)
    {
        if( isRaisedView )
        {
            if( isPressedView )
            {
                init( UIManager.getColor("controlLtHighlight"),
                      UIManager.getColor("controlDkShadow"),
                      UIManager.getColor("controlShadow"),
                      DEFAULT_SIZE, direction);
            }
            else
            {
                init( UIManager.getColor("controlHighlight"),
                      UIManager.getColor("controlShadow"),
                      UIManager.getColor("control"),
                      DEFAULT_SIZE, direction);
            }
        }
        else
        {
            if( isPressedView )
            {
                init( UIManager.getColor("controlDkShadow"),
                      UIManager.getColor("controlLtHighlight"),
                      UIManager.getColor("controlShadow"),
                      DEFAULT_SIZE, direction);
            }
            else
            {
                init( UIManager.getColor("controlShadow"),
                      UIManager.getColor("controlHighlight"),
                      UIManager.getColor("control"),
                      DEFAULT_SIZE, direction);
            }
        }
    }

    
    public BevelArrowIcon(Color edge1, Color edge2, Color fill, int size, int direction)
    {
        init(edge1, edge2, fill, size, direction);
    }

    
    public void paintIcon(Component c, Graphics g, int x, int y)
    {
        switch( m_direction ) {
            case SortButtonRenderer.DIR_DOWN: drawDownArrow(g, x, y); break;
            case SortButtonRenderer.DIR_UP  : drawUpArrow(g, x, y);   break;
            default                         : System.out.println("Invalid direction: " + m_direction); break;
        }
    }

    
    public int getIconWidth()
    {
        return( m_size );
    }

    
    public int getIconHeight()
    {
        return( m_size );
    }

    
    private void init(Color edge1, Color edge2, Color fill, int size, int direction)
    {
        m_edge1 = edge1;
        m_edge2 = edge2;
        m_fill = fill;
        m_size = size;
        m_direction = direction;
    }

    
    private void drawDownArrow(Graphics g, int xo, int yo)
    {
        g.setColor(m_edge1);
        g.drawLine(xo, yo,   xo+m_size-1, yo);
        g.drawLine(xo, yo+1, xo+m_size-3, yo+1);
        g.setColor(m_edge2);
        g.drawLine(xo+m_size-2, yo+1, xo+m_size-1, yo+1);
        int x = xo+1;
        int y = yo+2;
        int dx = m_size-6;      
        
        while( y+1 < yo+m_size )
        {
            g.setColor(m_edge1);
            g.drawLine(x, y,   x+1, y);
            g.drawLine(x, y+1, x+1, y+1);
            
            if( 0 < dx )
            {
                g.setColor(m_fill);
                g.drawLine(x+2, y,   x+1+dx, y);
                g.drawLine(x+2, y+1, x+1+dx, y+1);
            }

            g.setColor(m_edge2);
            g.drawLine(x+dx+2, y,   x+dx+3, y);
            g.drawLine(x+dx+2, y+1, x+dx+3, y+1);
            x += 1;
            y += 2;
            dx -= 2;     
        }

        g.setColor(m_edge1);
        g.drawLine(xo+(m_size/2), yo+m_size-1, xo+(m_size/2), yo+m_size-1); 
    }

    
    private void drawUpArrow(Graphics g, int xo, int yo)
    {
        g.setColor(m_edge1);
        int x = xo+(m_size/2);
        g.drawLine(x, yo, x, yo); 
        x--;
        int y = yo+1;
        int dx = 0;
        
        while( y+3 < yo+m_size )
        {
            g.setColor(m_edge1);
            g.drawLine(x, y,   x+1, y);
            g.drawLine(x, y+1, x+1, y+1);
            
            if( 0 < dx )
            {
                g.setColor(m_fill);
                g.drawLine(x+2, y,   x+1+dx, y);
                g.drawLine(x+2, y+1, x+1+dx, y+1);
            }
            
            g.setColor(m_edge2);
            g.drawLine(x+dx+2, y,   x+dx+3, y);
            g.drawLine(x+dx+2, y+1, x+dx+3, y+1);
            x -= 1;
            y += 2;
            dx += 2;     
        }

        g.setColor(m_edge1);
        g.drawLine(xo, yo+m_size-3,   xo+1, yo+m_size-3);
        g.setColor(m_edge2);
        g.drawLine(xo+2, yo+m_size-2, xo+m_size-1, yo+m_size-2);
        g.drawLine(xo, yo+m_size-1, xo+m_size, yo+m_size-1);
    }

}
