/*
 * SortButtonHeaderListener.java - Mouse listener for table header for
 *                                 TableSorter, original code from:
 *                                 http://www.senun.com/Left/Programming/
 *                                 Java_old/Examples_swing/SwingExamples.html
 *
 * Copyright (c) 2004 Gregory Kotsaftis
 * gregkotsaftis@yahoo.com
 * http://zeus-jscl.sourceforge.net/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package gr.zeus.ui.table.sort;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import javax.swing.table.JTableHeader;


public class SortButtonHeaderListener extends MouseAdapter {

    private JTableHeader m_header;
    private SortButtonRenderer m_renderer;
    
    
    public SortButtonHeaderListener(JTableHeader header, SortButtonRenderer renderer)
    {
        m_header   = header;
        m_renderer = renderer;
    }

    
    public void mousePressed(MouseEvent e)
    {
        int col = m_header.columnAtPoint( e.getPoint() );
        int sortCol = m_header.getTable().convertColumnIndexToModel( col );
        m_renderer.setPressedColumn( col );
        m_renderer.setSelectedColumn( col );
        m_header.repaint();
      
        if( m_header.getTable().isEditing() )
        {
            m_header.getTable().getCellEditor().stopCellEditing();
        }
      
        boolean isAscent = ( SortButtonRenderer.DIR_DOWN == m_renderer.getState(col) );

        ((SortableTableModel)m_header.getTable().getModel()).sortByColumn(sortCol, isAscent);
    }

    
    public void mouseReleased(MouseEvent e)
    {
        int col = m_header.columnAtPoint( e.getPoint() );
        m_renderer.setPressedColumn( -1 ); // clear
        m_header.repaint();
    }

}
