/*
 * SortableTableModel.java - Table model for TableSorter, original code from:
 *                           http://www.senun.com/Left/Programming/Java_old/
 *                           Examples_swing/SwingExamples.html
 *
 * Copyright (c) 2004 Gregory Kotsaftis
 * gregkotsaftis@yahoo.com
 * http://zeus-jscl.sourceforge.net/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package gr.zeus.ui.table.sort;

import java.util.Vector;
import javax.swing.table.DefaultTableModel;


public class SortableTableModel extends DefaultTableModel {

    private int[] m_indexes;
    private TableSorter m_sorter;

    
    public SortableTableModel()
    {
        super();
    }

    
    public SortableTableModel(int rowCount, int columnCount)
    {
        super(rowCount, columnCount);
    }
    
    
    public SortableTableModel(Object[][] data, Object[] columnNames)
    {
        super(data, columnNames);
    }

    
    public SortableTableModel(Object[] columnNames, int rowCount)
    {
        super(columnNames, rowCount);
    }
    
    
    public SortableTableModel(Vector columnNames, int rowCount)
    {
        super(columnNames, rowCount);
    }
    
    
    public SortableTableModel(Vector data, Vector columnNames)
    {
        super(data, columnNames);
    }
    
    
    public Object getValueAt(int row, int col)
    {
        int rowIndex = row;
        if( m_indexes != null )
        {
            rowIndex = m_indexes[row];
        }

        return( super.getValueAt(rowIndex, col) );
    }

    
    public void setValueAt(Object value, int row, int col)
    {
        int rowIndex = row;
        if( m_indexes != null )
        {
            rowIndex = m_indexes[row];
        }
    
        super.setValueAt(value, rowIndex, col);
    }

    
    public void sortByColumn(int column, boolean isAscent)
    {
        if( m_sorter == null )
        {
            m_sorter = new TableSorter(this);
        }
        
        m_sorter.sort(column, isAscent);   
        fireTableDataChanged();
    }

    
    public int[] getIndexes()
    {
        int n = getRowCount();
        
        if( m_indexes != null )
        {
            if( m_indexes.length == n )
            {
                return( m_indexes );
            }
        }

        m_indexes = new int[n];
        
        for(int i=0; i<n; i++)
        {
            m_indexes[i] = i;
        }

        return( m_indexes );
    }
    
}
