/*
 * CurrentDateHelper.java - Helper methods for current date and time
 *
 * Copyright (c) 2004 Gregory Kotsaftis
 * gregkotsaftis@yahoo.com
 * http://zeus-jscl.sourceforge.net/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package gr.zeus.util;

import java.util.Calendar;


public class CurrentDateHelper {    

    
    /**
     * Returns current date in java.util.Date object.
     */
    public static java.util.Date getCurrentDate()
    {
        Calendar cal = Calendar.getInstance();
        return( cal.getTime() );
    }
    
    
    /**
     * Returns current date in long number format.
     */
    public static long getCurrentDateLong()
    {
        Calendar cal = Calendar.getInstance();
        return( cal.getTimeInMillis() );
    }
    
    
    /**
     * Returns current year, e.g. 2004
     */
    public static int getCurrentYear()
    {
        Calendar cal = Calendar.getInstance();
        return( cal.get(Calendar.YEAR) );
    }
    
    
    /**
     * Returns current month, JANUARY=1,......,DECEMBER=12
     */
    public static int getCurrentMonth()
    {
        Calendar cal = Calendar.getInstance();
        return( cal.get(Calendar.MONTH)+1 );
    }
    

    /**
     * Returns current day in the month (1...31)
     */
    public static int getCurrentDay()
    {
        Calendar cal = Calendar.getInstance();
        return( cal.get(Calendar.DAY_OF_MONTH) );
    }
    
    
    /**
     * Returns current hour in 24 hours format.
     */
    public static int getCurrentHour()
    {
        Calendar cal = Calendar.getInstance();
        return( cal.get(Calendar.HOUR_OF_DAY) );
    }

    
    /**
     * Returns current minutes in hour.
     */
    public static int getCurrentMinutes()
    {
        Calendar cal = Calendar.getInstance();
        return( cal.get(Calendar.MINUTE) );
    }
    
    
    /**
     * Returns current seconds in hour.
     */
    public static int getCurrentSeconds()
    {
        Calendar cal = Calendar.getInstance();
        return( cal.get(Calendar.SECOND) );
    }
    
}
